@@ -1,6 +1,6 @@
 from django.contrib.contenttypes.models import ContentType
 from django.forms import (
-    CharField, FloatField
+    CharField, FloatField, HiddenInput
 )
 
 from netbox.forms import (
@@ -38,11 +38,18 @@ class LinuxDeviceForm(NetBoxModelForm):
         model = LinuxDevice
 
         fields = (
+            'content_type',
+            'object_id',
             "device",
             "type",
             "size",
         )
+        widgets = {
+            'content_type': HiddenInput(),
+            'object_id': HiddenInput(),
+        }
 
+"""
     def save(self, *args, **kwargs):
         object_pk = self.cleaned_data['parent_object'].pk
 
@@ -52,6 +59,7 @@ class LinuxDeviceForm(NetBoxModelForm):
         linux_device = super().save(*args, **kwargs)
 
         return linux_device
+"""
 
 
 class LinuxDeviceFilterForm(NetBoxModelFilterSetForm):
