@@ -15,10 +15,24 @@ from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
 
-from netbox_storage.models import Drive, LogicalVolume
+from netbox_storage.models import LogicalVolume, VolumeGroup
 
 
 class LogicalVolumeForm(NetBoxModelForm):
+    lv_name = CharField(
+        label="LV Name",
+        help_text="Logical Volume Name e.g. lv_docker",
+    )
+    vg = DynamicModelChoiceField(
+        queryset=VolumeGroup.objects.all(),
+        label="VG Name",
+        help_text="Volume Group Name e.g. vg_docker",
+    )
+    size = FloatField(
+        label="Size (MB)",
+        help_text="The size of the logical volume e.g. 25",
+        validators=[MinValueValidator(0.1)],
+    )
     description = CharField(
         required=False,
         label="Description",
@@ -28,9 +42,12 @@ class LogicalVolumeForm(NetBoxModelForm):
     class Meta:
         model = LogicalVolume
 
-        fields = (
-            "description",
-        )
+        fields = [
+            'lv_name',
+            'vg',
+            'size',
+            'description'
+        ]
 
 
 class LogicalVolumeFilterForm(NetBoxModelFilterSetForm):
