@@ -11,7 +11,7 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
-    StorageConfigurationDrive, MountedVolume, LinuxDevice, TemplateConfigurationDrive
+    MountedVolume, LinuxDevice, TemplateConfigurationDrive
 from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
@@ -36,7 +36,7 @@ class LVMTemplateForm(NetBoxModelForm):
         help_text="Volume Group Name e.g. vg_docker",
     )
     size = FloatField(
-        label="Size (GB)",
+        label="Size (MB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
@@ -56,7 +56,7 @@ class LVMTemplateForm(NetBoxModelForm):
         required=False,
         label="Filesystem Options",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
-        default='defaults',
+        initial='defaults',
     )
     checkbox_partition = BooleanField(
         label="Create extra partition",
@@ -66,10 +66,15 @@ class LVMTemplateForm(NetBoxModelForm):
 
     fieldsets = (
         (
-            "Drive Cluster Config",
+            "Template for Platform",
+            (
+                "platform",
+            ),
+        ),
+        (
+            "Drive & Partition Config",
             (
                 "drive",
-                "platform",
                 "checkbox_partition"
             ),
         ),
@@ -79,6 +84,11 @@ class LVMTemplateForm(NetBoxModelForm):
                 "lv_name",
                 "vg_name",
                 "size",
+            ),
+        ),
+        (
+            "Create Filesystem and mount it",
+            (
                 "mountpoint",
                 "fs_type",
                 "fs_options",
@@ -120,22 +130,12 @@ class LVMTemplateForm(NetBoxModelForm):
             pv_linux_device = linux_parent_device
 
         volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        #print(f"Volume Group ID: {volume_group.id}")
 
         pv = PhysicalVolume.objects.create(linux_device=pv_linux_device, vg=volume_group)
-        #pv.save()
-        #print(f"Physical Volume ID: {pv.id}")
 
-        # Add linux_device for lvm
         lv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='logicalvolume').pk
 
-        #print(f"Linux Device ID: {linux_device_mapper.id}")
-
         self.instance.vg = volume_group
-        #lv = LogicalVolume.objects.create(vg=volume_group, lv_name=self.cleaned_data['lv_name'],
-        #                                  size=self.cleaned_data['size'], device=linux_device_mapper)
-        #lv.save()
-        #print(f"{lv}")
         lv = super().save(*args, **kwargs)
 
         linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
@@ -156,7 +156,7 @@ class LVMTemplateForm(NetBoxModelForm):
 #
 class DriveTemplateForm(NetBoxModelForm):
     size = FloatField(
-        label="Size (GB)",
+        label="Size (MB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
@@ -177,13 +177,18 @@ class DriveTemplateForm(NetBoxModelForm):
     )
 
     fieldsets = (
+        (
+            "Template for Platform",
+            (
+                "platform",
+            ),
+        ),
         (
             "Drive Config",
             (
                 "cluster_type",
                 "cluster",
                 "size",
-                "platform",
             ),
         ),
     )
@@ -199,17 +204,17 @@ class DriveTemplateForm(NetBoxModelForm):
         self.instance.drive = drive
         template_configuration = super().save(*args, **kwargs)
         drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
-        linux_device = LinuxDevice.objects.create(device=drive.device_name(),
-                                                  type='Disk',
-                                                  size=self.cleaned_data['size'],
-                                                  object_id=drive.pk,
-                                                  content_type_id=drive_type_pk)
+        LinuxDevice.objects.create(device=drive.device_name(),
+                                   type='Disk',
+                                   size=self.cleaned_data['size'],
+                                   object_id=drive.pk,
+                                   content_type_id=drive_type_pk)
         return template_configuration
 
 
 class PartitionTemplateForm(NetBoxModelForm):
     size = FloatField(
-        label="Size (GB)",
+        label="Size (MB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
@@ -221,11 +226,13 @@ class PartitionTemplateForm(NetBoxModelForm):
         queryset=Platform.objects.all(),
         help_text="Mapping between Volume and platform e.g. Rocky Linux 8",
     )
-    mount_point = CharField(
-        label="mount_point",
+    mountpoint = CharField(
+        required=False,
+        label="Mountpoint",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     fs_type = DynamicModelChoiceField(
+        required=False,
         queryset=Filesystem.objects.all(),
         label="Filesystem Name",
         widget=APISelect(
@@ -246,17 +253,27 @@ class PartitionTemplateForm(NetBoxModelForm):
 
     fieldsets = (
         (
-            "Select drive",
+            "Template for Platform",
             (
-                "drive",
                 "platform",
             ),
         ),
         (
             "Select drive",
             (
-                "mount_point",
+                "drive",
+            ),
+        ),
+        (
+            "Size of new Partition",
+            (
                 "size",
+            ),
+        ),
+        (
+            "Create Filesystem and mount it",
+            (
+                "mountpoint",
                 "fs_type",
                 "fs_options",
                 "label",
@@ -264,43 +281,40 @@ class PartitionTemplateForm(NetBoxModelForm):
         ),
     )
 
-# /boot/efi --fstype="efi" --ondisk=sda --size=126 --fsoptions="umask=0077,shortname=winnt" --label=boot_efi
     class Meta:
-        model = Partition
+        model = LinuxDevice
         fields = [
             "size"
         ]
 
     def save(self, *args, **kwargs):
         print(f"drive: {self.cleaned_data['drive']}")
-        print(f"ID OF drive: {self.cleaned_data['drive'].id}")
-        print(f"ID OF drive: {self.cleaned_data['drive'].cluster}")
         new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
         device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
         print(f"Partition Count: {new_partition_count}")
         print(f"Device Name: {device_name_prefix}")
         device_name = device_name_prefix + str(new_partition_count)
 
-        mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mount_point'],
-                                                      fs_type=self.cleaned_data['fs_type'],
-                                                      options=self.cleaned_data['fs_options'])
+        linux_device_type_pk = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
 
-        linux_device = LinuxDevice.objects.create(device=device_name, type='efi', mounted_volume=mounted_volume)
+        self.instance.device = device_name
+        self.instance.type = 'Partition'
+        self.instance.object_id = self.cleaned_data['drive'].pk
+        self.instance.content_type_id = linux_device_type_pk
+        linux_device_partition = super().save(*args, **kwargs)
 
-        self.instance.drive = self.cleaned_data['drive']
-        self.instance.device = linux_device
-        self.instance.type = 'vfat'
-        partition = super().save(*args, **kwargs)
-
-        # print(f"{self.cleaned_data['size']}")
-        return partition
+        MountedVolume.objects.create(linux_device=linux_device_partition,
+                                     mount_point=self.cleaned_data['mountpoint'],
+                                     fs_type=self.cleaned_data['fs_type'],
+                                     options=self.cleaned_data['fs_options'])
+        return linux_device_partition
 
 
 class VolumeSimpleForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
     size = FloatField(
-        label="Size (GB)",
+        label="Size (MB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
         required=False
@@ -315,8 +329,8 @@ class VolumeSimpleForm(NetBoxModelForm):
         help_text="The volume group name e.g. vg_data",
         required=False
     )
-    mount_point = CharField(
-        label="mount_point",
+    mountpoint = CharField(
+        label="Mountpoint",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
         required=False
     )
@@ -362,13 +376,4 @@ class VolumeSimpleForm(NetBoxModelForm):
 
     def save(self, *args, **kwargs):
         drive = super().save(*args, **kwargs)
-
-        # Assign/clear this IPAddress as the primary for the associated Device/VirtualMachine.
-        # print(f"{self.instance}")
-        print(f"{self.cleaned_data['lv_data']}")
-        print(f"{self.cleaned_data['vg_data']}")
-        print(f"{self.cleaned_data['size']}")
-        print(f"{self.cleaned_data['mount_point']}")
-        print(f"{self.cleaned_data['fs']}")
-
         return drive
