@@ -47,8 +47,7 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         obj = self.context.get("object")
 
         drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
-        partition_dict = {
-        }
+        partition_dict = {}
         for drive_id in drives_id:
             print(f"Drive ID: {drive_id['drive']}")
             drive = Drive.objects.get(pk=drive_id['drive'])
