@@ -1,12 +1,8 @@
 from netbox.views import generic
 
 from netbox_storage.filters import PhysicalVolumeFilter
-from netbox_storage.forms import (
-  #  PhysicalVolumeImportForm,
-    PhysicalVolumeFilterForm,
-    PhysicalVolumeForm,
- #   PhysicalVolumeBulkEditForm
-)
+from netbox_storage.forms import PhysicalVolumeFilterForm, PhysicalVolumeForm, PhysicalVolumeBulkEditForm, \
+    PhysicalVolumeImportForm
 from netbox_storage.models import PhysicalVolume
 from netbox_storage.tables import PhysicalVolumeTable
 
@@ -33,7 +29,6 @@ class PhysicalVolumeDeleteView(generic.ObjectDeleteView):
     default_return_url = "plugins:netbox_storage:physicalvolume_list"
 
 
-"""
 class PhysicalVolumeBulkImportView(generic.BulkImportView):
     queryset = PhysicalVolume.objects.all()
     model_form = PhysicalVolumeImportForm
@@ -51,4 +46,3 @@ class PhysicalVolumeBulkEditView(generic.BulkEditView):
 class PhysicalVolumeBulkDeleteView(generic.BulkDeleteView):
     queryset = PhysicalVolume.objects.all()
     table = PhysicalVolumeTable
-"""
\ No newline at end of file
